import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// dollors 
const numberFormat = number =>
  	(Math.abs(Number(number))) + " $" ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.basic_cost)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.basic_cost))
  	.on("mouseover", d => console.log(d.data.basic_cost));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each country as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.basic_cost));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.country);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.basic_cost));
}

// url of my data giest

const csvUrl =
 'https://gist.githubusercontent.com/Bhanuteja-1807/6fb223c90d4e286f46309b8a68976c90/raw/1339e13aa24b41303c79305eb279e3665a91d56d/Cost_basic.csv';


//Load the data and display basic cost of netflix 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.basic_cost-data1.basic_cost);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});